@@ -46,7 +46,7 @@ get_colors_from_NASIS_db <- function(SS = TRUE, method = "dominant", mixColors =
     return(data.frame())
 
   # toggle selected set vs. local DB
-  if (SS == FALSE) {
+  if (isFALSE(SS)) {
     q <- gsub(pattern = '_View_1', replacement = '', x = q, fixed = TRUE)
   }
 
