@@ -25,7 +25,7 @@ get_ecosite_history_from_NASIS_db <- function(best = TRUE, SS = TRUE, es_classif
   ORDER BY siteiid;"
   
   # toggle selected set vs. local DB
-  if (SS == FALSE) {
+  if (isFALSE(SS)) {
     q.ecosite <- gsub(pattern = '_View_1', replacement = '', x = q.ecosite, fixed = TRUE)
   }
   
