@@ -52,13 +52,13 @@ test_that("SDA_query() returns expected result", {
   skip_if(inherits(x.2, 'try-error'))
   
   # table dimensions
-  expect_equal(nrow(x.1), 1)
-  expect_equal(ncol(x.1), 2)
+  expect_equivalent(nrow(x.1), 1)
+  expect_equivalent(ncol(x.1), 2)
 
   # expected results
   x.12 <- do.call('rbind', x.2)
-  expect_equal(x.1$areasymbol, 'CA630')
-  expect_equal(x.12$areasymbol, c('CA630', 'CA664'))
+  expect_equivalent(x.1$areasymbol, 'CA630')
+  expect_equivalent(x.12$areasymbol, c('CA630', 'CA664'))
 
 })
 
@@ -109,7 +109,7 @@ test_that("SDA_spatialQuery() simple spatial query, tabular results", {
     
     # testing known values
     expect_true(inherits(res, 'data.frame'))
-    expect_equal(nrow(res), 1)
+    expect_equivalent(nrow(res), 1)
     expect_match(res$muname, 'Diablo')
   }
   
@@ -119,7 +119,7 @@ test_that("SDA_spatialQuery() simple spatial query, tabular results", {
   skip_if(inherits(res, 'try-error'))
   
   expect_true(inherits(res, 'data.frame'))
-  expect_equal(nrow(res), 1)
+  expect_equivalent(nrow(res), 1)
   expect_match(res$areasymbol, 'CA641')
   
 })
@@ -142,7 +142,7 @@ test_that("SDA_spatialQuery() simple spatial query, spatial results", {
   
   # testing known values
   expect_true(inherits(res, 'sf'))
-  expect_equal(nrow(res), 1)
+  expect_equivalent(nrow(res), 1)
 
 
   # test with db = "STATSGO"
@@ -152,7 +152,7 @@ test_that("SDA_spatialQuery() simple spatial query, spatial results", {
   
   # testing known values
   expect_true(inherits(res, 'sf'))
-  expect_equal(nrow(res), 1)
+  expect_equivalent(nrow(res), 1)
   
   # test with what = "sapolygon" 
   res <- suppressWarnings(SDA_spatialQuery(p, what = "sapolygon"))
@@ -161,7 +161,7 @@ test_that("SDA_spatialQuery() simple spatial query, spatial results", {
   
   # testing known values
   expect_true(inherits(res, 'sf'))
-  expect_equal(nrow(res), 1)
+  expect_equivalent(nrow(res), 1)
 
 })
 
@@ -183,10 +183,10 @@ test_that("SDA_spatialQuery() spatial query of MUKEY with multiple features", {
   # if the result set is empty rather than an error, SDA_query() result can be NULL
   skip_if(is.null(res) || inherits(res, 'try-error'))
   
-  expect_equal(nrow(res), 2)
+  expect_equivalent(nrow(res), 2)
   
   res2 <- SDA_spatialQuery(x, db = "STATSGO")
-  expect_equal(nrow(res), 2)
+  expect_equivalent(nrow(res), 2)
 })
 
 test_that("SDA_query() interprets column names", {
@@ -200,10 +200,7 @@ test_that("SDA_query() interprets column names", {
   skip_if(inherits(x.3, 'try-error'))
   
   # x.3 is from the component table
-  expect_equal(
-    names(x.3),
-    c("mukey", "cokey", "compkind", "comppct_r", "majcompflag", "elev_r", "slope_r", "wei", "weg")
-  )
+  expect_named(x.3, c("mukey", "cokey", "compkind", "comppct_r", "majcompflag", "elev_r", "slope_r", "wei", "weg"))
 
 })
 
