@@ -11,7 +11,7 @@ test_that("estimateSTR() basic functionality", {
   # vector of factors
   x <- estimateSTR(mast=17, mean.summer = 22, mean.winter = 12)
   expect_true(inherits(x, 'factor'))
-  expect_equal(levels(x), expected.str.levels)
+  expect_equivalent(levels(x), expected.str.levels)
   
 })
 
@@ -25,7 +25,7 @@ test_that("estimateSTR(): specific examples", {
   # thermic / hyperthermic
   # vectorized input
   x <- estimateSTR(mast=c(17,25), mean.summer = c(22, 26), mean.winter = c(12, 14))
-  expect_equal(as.character(x), c('thermic', 'hyperthermic'))
+  expect_equivalent(as.character(x), c('thermic', 'hyperthermic'))
   
   # mesic
   x <- estimateSTR(mast = 12, mean.summer = 15, mean.winter = 8)
