@@ -14,12 +14,12 @@ test_that("SDA interpretations (dominant component) works", {
 
   res <- get_SDA_interpretation("FOR - Potential Seedling Mortality",
                                 method = "Dominant Component", areasymbols = target_areas)
-  expect_equal(nrow(res), target_area_rows)
+  expect_equivalent(nrow(res), target_area_rows)
 
   res <- get_SDA_interpretation(c("FOR - Potential Seedling Mortality",
                                   "FOR - Road Suitability (Natural Surface)"),
                                 method = "Dominant Component", mukeys = target_mukeys)
-  expect_equal(sort(res$mukey), sort(target_mukeys))
+  expect_equivalent(sort(res$mukey), sort(target_mukeys))
 })
 
 test_that("SDA interpretations (dominant condition) works", {
@@ -33,14 +33,14 @@ test_that("SDA interpretations (dominant condition) works", {
   res <- get_SDA_interpretation("FOR - Potential Seedling Mortality",
                                 method = "Dominant Condition", areasymbols = target_areas)
   skip_if(is.null(res))
-  expect_equal(nrow(res), target_area_rows)
+  expect_equivalent(nrow(res), target_area_rows)
 
 
   res <- get_SDA_interpretation(c("FOR - Potential Seedling Mortality",
                                   "FOR - Road Suitability (Natural Surface)"),
                                 method = "Dominant Condition", mukeys = target_mukeys)
   skip_if(is.null(res))
-  expect_equal(sort(res$mukey), sort(target_mukeys))
+  expect_equivalent(sort(res$mukey), sort(target_mukeys))
 })
 
 test_that("SDA interpretations (weighted average) works", {
@@ -54,14 +54,14 @@ test_that("SDA interpretations (weighted average) works", {
   res <- get_SDA_interpretation("FOR - Potential Seedling Mortality",
                                 method = "Weighted Average", areasymbols = target_areas)
   skip_if(is.null(res))
-  expect_equal(nrow(res), target_area_rows)
+  expect_equivalent(nrow(res), target_area_rows)
 
 
   res <- get_SDA_interpretation(c("FOR - Potential Seedling Mortality",
                                   "FOR - Road Suitability (Natural Surface)"),
                                 method = "Weighted Average", mukeys = target_mukeys)
   skip_if(is.null(res))
-  expect_equal(sort(res$mukey), sort(target_mukeys))
+  expect_equivalent(sort(res$mukey), sort(target_mukeys))
 })
 
 test_that("SDA interpretations (no aggregation) works", {
@@ -77,7 +77,7 @@ test_that("SDA interpretations (no aggregation) works", {
                                 method = "NONE",
                                 areasymbols = target_areas)
   skip_if(is.null(res))
-  expect_equal(nrow(res), target_area_rows_all)
+  expect_equivalent(nrow(res), target_area_rows_all)
 
 
 })
